==> push_framework-2.2.8.tar.gz: push_framework/modules/eca/src/EventSubscriber/EcaPushFramework.php <==
<?php

namespace Drupal\eca_push_framework\EventSubscriber;

use Drupal\eca\EcaEvents;
use Drupal\eca\Event\AfterInitialExecutionEvent;
use Drupal\eca\Event\BeforeInitialExecutionEvent;
use Drupal\eca\EventSubscriber\EcaBase;
use Drupal\eca\Plugin\DataType\DataTransferObject;
use Drupal\eca_push_framework\Plugin\ECA\Event\ChannelEvent;
use Drupal\eca_push_framework\Plugin\ECA\Event\EcaPushFrameworkEvent;
use Drupal\push_framework\Event\ChannelEventBase;
use Drupal\push_framework\Event\ChannelEventLanguageBase;
use Drupal\push_framework\Event\ChannelPostRender;
use Drupal\push_framework\Event\ChannelPrepareTemplates;
use Drupal\push_framework\Event\ChannelPreRender;

/**
 * ECA event subscriber regarding form events.
 */
class EcaPushFramework extends EcaBase {

  /**
   * Subscriber method before initial execution.
   *
   * Adds the event data to the token service.
   *
   * @param \Drupal\eca\Event\BeforeInitialExecutionEvent $before_event
   *   The according event.
   *
   * @throws \Drupal\Core\TypedData\Exception\MissingDataException
   */
  public function onBeforeInitialExecution(BeforeInitialExecutionEvent $before_event): void {
    $event = $before_event->getEvent();
    if ($event instanceof ChannelEventBase) {
      $dto = DataTransferObject::create();
      $dto->set('channel', $event->getChannelPlugin()->getPluginId());
      $dto->set('recipient', $event->getUser());
      $dto->set('entity', $event->getEntity());
      $dto->set('display_mode', $event->getDisplayMode());
      if ($event instanceof ChannelPrepareTemplates) {
        $dto->set('subject', $event->getSubject());
        $dto->set('body', $event->getBody());
        $dto->set('text_format', $event->getTextFormat());
        $dto->set('is_html', $event->isHtml());
      }
      if ($event instanceof ChannelEventLanguageBase) {
        $dto->set('language_key', $event->getLanguageKey());
      }
      if ($event instanceof ChannelPreRender) {
        $dto->set('elements', $event->getElements());
      }
      if ($event instanceof ChannelPostRender) {
        $dto->set('output', $event->getOutput());
      }
      $this->tokenService->addTokenData('push_notification', $dto);
    }
  }

  /**
   * Subscriber method after initial execution.
   *
   * Removes the form data provider from the Token service.
   *
   * @param \Drupal\eca\Event\AfterInitialExecutionEvent $after_event
   *   The according event.
   *
   * @throws \Drupal\Core\TypedData\Exception\MissingDataException
   */
  public function onAfterInitialExecution(AfterInitialExecutionEvent $after_event): void {
    $event = $after_event->getEvent();
    if ($event instanceof ChannelEventBase) {
      $dto = $this->tokenService->getTokenData('push_notification');
      if ($dto instanceof DataTransferObject) {
        if ($event instanceof ChannelPrepareTemplates) {
          $event
            ->setDisplayMode($dto->get('display_mode')->getString())
            ->setSubject($dto->get('subject')->getString())
            ->setBody($dto->get('body')->getString())
            ->setTextFormat($dto->get('text_format')->getString())
            ->setIsHtml((bool) $dto->get('is_html')->getValue());
        }
        if ($event instanceof ChannelPreRender) {
          $event->setElements((array) $dto->get('elements'));
        }
        if ($event instanceof ChannelPostRender) {
          $event->setOutput($dto->get('output')->getString());
        }
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events = [];
    foreach (ChannelEvent::definitions() as $definition) {
      $events[$definition['event_name']][] = ['onEvent'];
    }
    foreach (EcaPushFrameworkEvent::definitions() as $definition) {
      $events[$definition['event_name']][] = ['onEvent'];
    }
    $events[EcaEvents::BEFORE_INITIAL_EXECUTION][] = [
      'onBeforeInitialExecution',
      -100,
    ];
    $events[EcaEvents::AFTER_INITIAL_EXECUTION][] = [
      'onAfterInitialExecution',
      100,
    ];
    return $events;
  }

}

==> push_framework-2.3.1.tar.gz: push_framework/modules/eca/src/EventSubscriber/EcaPushFramework.php <==
<?php

namespace Drupal\eca_push_framework\EventSubscriber;

use Drupal\eca\EcaEvents;
use Drupal\eca\Event\AfterInitialExecutionEvent;
use Drupal\eca\EventSubscriber\EcaExecutionSubscriberBase;
use Drupal\eca\Plugin\DataType\DataTransferObject;
use Drupal\push_framework\Event\ChannelEventBase;
use Drupal\push_framework\Event\ChannelPostRender;
use Drupal\push_framework\Event\ChannelPrepareTemplates;
use Drupal\push_framework\Event\ChannelPreRender;

/**
 * ECA event subscriber regarding form events.
 */
class EcaPushFramework extends EcaExecutionSubscriberBase {

  /**
   * Subscriber method after initial execution.
   *
   * Removes the form data provider from the Token service.
   *
   * @param \Drupal\eca\Event\AfterInitialExecutionEvent $after_event
   *   The according event.
   *
   * @throws \Drupal\Core\TypedData\Exception\MissingDataException
   */
  public function onAfterInitialExecution(AfterInitialExecutionEvent $after_event): void {
    $event = $after_event->getEvent();
    if ($event instanceof ChannelEventBase) {
      $dto = $this->tokenService->getTokenData('push_notification');
      if ($dto instanceof DataTransferObject) {
        if ($event instanceof ChannelPrepareTemplates) {
          $event
            ->setDisplayMode($dto->get('display_mode')->getString())
            ->setSubject($dto->get('subject')->getString())
            ->setBody($dto->get('body')->getString())
            ->setTextFormat($dto->get('text_format')->getString())
            ->setIsHtml((bool) $dto->get('is_html')->getValue());
        }
        if ($event instanceof ChannelPreRender) {
          $event->setElements((array) $dto->get('elements'));
        }
        if ($event instanceof ChannelPostRender) {
          $event->setOutput($dto->get('output')->getString());
        }
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events = [];
    $events[EcaEvents::AFTER_INITIAL_EXECUTION][] = [
      'onAfterInitialExecution',
      100,
    ];
    return $events;
  }

}
